@@ -62,10 +62,11 @@ class Apps:
 
 class App:
 
-    def __init__(self, spec=None, add_book=None, xl=None):
+    def __init__(self, spec=None, add_book=None, xl=None, visible=True):
         if xl is None:
-            self.xl = appscript.app(name=spec or 'Microsoft Excel', newinstance=True, terms=mac_dict)
-            self.activate()  # Makes it behave like on Windows
+            self.xl = appscript.app(name=spec or 'Microsoft Excel', newinstance=True, terms=mac_dict, hide=not visible)
+            if visible:
+                self.activate()  # Makes it behave like on Windows
         elif isinstance(xl, int):
             self.xl = appscript.app(pid=xl, terms=mac_dict)
         else:
@@ -285,9 +286,9 @@ class Book:
         display_alerts = self.app.display_alerts
         self.app.display_alerts = False
         # This causes a pop-up if there's a pw protected sheet, see #1377
-        hfs_path = self.xl.properties().get(kw.full_name)
+        path = self.xl.properties().get(kw.full_name)
         self.app.display_alerts = display_alerts
-        return hfs_to_posix_path(hfs_path)
+        return path
 
     @property
     def names(self):
