@@ -22,9 +22,14 @@ def get_addin_path():
 
 
 def addin_install(args):
+    if args is None:
+        unprotected = False
+    else:
+        unprotected = args.unprotected
     try:
         addin_path = get_addin_path()
-        shutil.copyfile(os.path.join(this_dir, 'addin', 'xlwings.xlam'), addin_path)
+        addin_name = 'xlwings_unprotected.xlam' if unprotected else 'xlwings.xlam'
+        shutil.copyfile(os.path.join(this_dir, 'addin', addin_name), addin_path)
         print('Successfully installed the xlwings add-in! Please restart Excel.')
         if sys.platform.startswith('darwin'):
             runpython_install(None)
@@ -79,8 +84,6 @@ def quickstart(args):
     # Python file
     with open(os.path.join(project_path, project_name + '.py'), 'w') as python_module:
         python_module.write('import xlwings as xw\n\n\n')
-        if sys.platform.startswith('win'):
-            python_module.write('@xw.sub  # only required if you want to import it or run it via UDF Server\n')
         python_module.write('def main():\n')
         python_module.write('    wb = xw.Book.caller()\n')
         python_module.write('    sheet = wb.sheets[0]\n')
@@ -91,7 +94,7 @@ def quickstart(args):
         if sys.platform.startswith('win'):
             python_module.write('@xw.func\n')
             python_module.write('def hello(name):\n')
-            python_module.write('    return "hello {0}".format(name)\n\n\n')
+            python_module.write('    return f"Hello {name}!"\n\n\n')
         python_module.write('if __name__ == "__main__":\n')
         python_module.write('    xw.Book("{0}.xlsm").set_mock_caller()\n'.format(project_name))
         python_module.write('    main()\n')
@@ -184,7 +187,7 @@ def config_create(args):
         extension = 'MAC' if sys.platform.startswith('darwin') else 'WIN'
         settings.append('"INTERPRETER_{}","{}"\n'.format(extension, sys.executable))
     if os.path.exists(xw.USER_CONFIG_FILE) and not force:
-        print("There is already an existing config file. Run with --force if you want to overwrite.")
+        print("There is already an existing ~/.xlwings/xlwings.conf file. Run 'xlwings config create --force' if you want to reset your configuration.")
     else:
         with open(xw.USER_CONFIG_FILE, 'w') as f:
             f.writelines(settings)
@@ -224,7 +227,7 @@ def code_embed(args):
 
 
 def main():
-    print('xlwings version: ' + '0.20.3')
+    print('xlwings version: ' + '0.20.8')
     parser = argparse.ArgumentParser()
     subparsers = parser.add_subparsers(dest='command')
     subparsers.required = True
@@ -233,11 +236,13 @@ def main():
     addin_parser = subparsers.add_parser('addin', help='Run "xlwings addin install" to install the Excel add-in '
                                                        '(will be copied to the XLSTART folder). Instead of "install" you can '
                                                        'also use "update", "remove" or "status". Note that this command '
-                                                       'may take a while.')
+                                                       'may take a while. Use the "--unprotected" flag to install the '
+                                                       'add-in without password protection.')
     addin_subparsers = addin_parser.add_subparsers(dest='subcommand')
     addin_subparsers.required = True
 
     addin_install_parser = addin_subparsers.add_parser('install')
+    addin_install_parser.add_argument("-u", "--unprotected", action='store_true', help='Install the add-in without the password protection.')
     addin_install_parser.set_defaults(func=addin_install)
 
     addin_update_parser = addin_subparsers.add_parser('update')
@@ -280,7 +285,7 @@ def main():
 
     # restapi run
     restapi_parser = subparsers.add_parser('restapi',
-                                           help='Use "xlwings restapi run" to run the xlwings REST API via Flask 0.20.3 '
+                                           help='Use "xlwings restapi run" to run the xlwings REST API via Flask 0.20.8 '
                                                 'server. Accepts "--host" and "--port" as optional arguments.')
     restapi_subparser = restapi_parser.add_subparsers(dest='subcommand')
     restapi_subparser.required = True
