@@ -207,7 +207,7 @@ class App:
 
     def __init__(self, visible=None, spec=None, add_book=True, impl=None):
         if impl is None:
-            self.impl = xlplatform.App(spec=spec, add_book=add_book)
+            self.impl = xlplatform.App(spec=spec, add_book=add_book, visible=visible)
             if visible or visible is None:
                 self.visible = True
         else:
@@ -2288,7 +2288,82 @@ class Chart:
     @property
     def chart_type(self):
         """
-        Returns and sets the chart type of the chart.
+        Returns and sets the chart type of the chart. The following chart types are available:
+
+        ``3d_area``,
+        ``3d_area_stacked``,
+        ``3d_area_stacked_100``,
+        ``3d_bar_clustered``,
+        ``3d_bar_stacked``,
+        ``3d_bar_stacked_100``,
+        ``3d_column``,
+        ``3d_column_clustered``,
+        ``3d_column_stacked``,
+        ``3d_column_stacked_100``,
+        ``3d_line``,
+        ``3d_pie``,
+        ``3d_pie_exploded``,
+        ``area``,
+        ``area_stacked``,
+        ``area_stacked_100``,
+        ``bar_clustered``,
+        ``bar_of_pie``,
+        ``bar_stacked``,
+        ``bar_stacked_100``,
+        ``bubble``,
+        ``bubble_3d_effect``,
+        ``column_clustered``,
+        ``column_stacked``,
+        ``column_stacked_100``,
+        ``combination``,
+        ``cone_bar_clustered``,
+        ``cone_bar_stacked``,
+        ``cone_bar_stacked_100``,
+        ``cone_col``,
+        ``cone_col_clustered``,
+        ``cone_col_stacked``,
+        ``cone_col_stacked_100``,
+        ``cylinder_bar_clustered``,
+        ``cylinder_bar_stacked``,
+        ``cylinder_bar_stacked_100``,
+        ``cylinder_col``,
+        ``cylinder_col_clustered``,
+        ``cylinder_col_stacked``,
+        ``cylinder_col_stacked_100``,
+        ``doughnut``,
+        ``doughnut_exploded``,
+        ``line``,
+        ``line_markers``,
+        ``line_markers_stacked``,
+        ``line_markers_stacked_100``,
+        ``line_stacked``,
+        ``line_stacked_100``,
+        ``pie``,
+        ``pie_exploded``,
+        ``pie_of_pie``,
+        ``pyramid_bar_clustered``,
+        ``pyramid_bar_stacked``,
+        ``pyramid_bar_stacked_100``,
+        ``pyramid_col``,
+        ``pyramid_col_clustered``,
+        ``pyramid_col_stacked``,
+        ``pyramid_col_stacked_100``,
+        ``radar``,
+        ``radar_filled``,
+        ``radar_markers``,
+        ``stock_hlc``,
+        ``stock_ohlc``,
+        ``stock_vhlc``,
+        ``stock_vohlc``,
+        ``surface``,
+        ``surface_top_view``,
+        ``surface_top_view_wireframe``,
+        ``surface_wireframe``,
+        ``xy_scatter``,
+        ``xy_scatter_lines``,
+        ``xy_scatter_lines_no_markers``,
+        ``xy_scatter_smooth``,
+        ``xy_scatter_smooth_no_markers``
 
         .. versionadded:: 0.1.1
         """
